# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Contact(pulumi.CustomResource):
    alert_notifications: pulumi.Output[bool]
    """
    Whether to send security alerts notifications to the security contact.
    """
    alerts_to_admins: pulumi.Output[bool]
    """
    Whether to send security alerts notifications to subscription admins.
    """
    email: pulumi.Output[str]
    """
    The email of the Security Center Contact.
    """
    phone: pulumi.Output[str]
    """
    The phone number of the Security Center Contact.
    """
    def __init__(__self__, resource_name, opts=None, alert_notifications=None, alerts_to_admins=None, email=None, phone=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages the subscription's Security Center Contact.
        
        > **NOTE:** Owner access permission is required. 
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] alert_notifications: Whether to send security alerts notifications to the security contact.
        :param pulumi.Input[bool] alerts_to_admins: Whether to send security alerts notifications to subscription admins.
        :param pulumi.Input[str] email: The email of the Security Center Contact.
        :param pulumi.Input[str] phone: The phone number of the Security Center Contact.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/security_center_contact.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if alert_notifications is None:
                raise TypeError("Missing required property 'alert_notifications'")
            __props__['alert_notifications'] = alert_notifications
            if alerts_to_admins is None:
                raise TypeError("Missing required property 'alerts_to_admins'")
            __props__['alerts_to_admins'] = alerts_to_admins
            if email is None:
                raise TypeError("Missing required property 'email'")
            __props__['email'] = email
            __props__['phone'] = phone
        super(Contact, __self__).__init__(
            'azure:securitycenter/contact:Contact',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, alert_notifications=None, alerts_to_admins=None, email=None, phone=None):
        """
        Get an existing Contact resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] alert_notifications: Whether to send security alerts notifications to the security contact.
        :param pulumi.Input[bool] alerts_to_admins: Whether to send security alerts notifications to subscription admins.
        :param pulumi.Input[str] email: The email of the Security Center Contact.
        :param pulumi.Input[str] phone: The phone number of the Security Center Contact.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/security_center_contact.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["alert_notifications"] = alert_notifications
        __props__["alerts_to_admins"] = alerts_to_admins
        __props__["email"] = email
        __props__["phone"] = phone
        return Contact(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Controller(pulumi.CustomResource):
    data_plane_fqdn: pulumi.Output[str]
    """
    DNS name for accessing DataPlane services.
    """
    host_suffix: pulumi.Output[str]
    """
    The host suffix for the DevSpace Controller.
    """
    location: pulumi.Output[str]
    """
    Specifies the supported location where the DevSpace Controller should exist. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    Specifies the name of the DevSpace Controller. Changing this forces a new resource to be created.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group under which the DevSpace Controller resource has to be created. Changing this forces a new resource to be created.
    """
    sku: pulumi.Output[dict]
    """
    A `sku` block as documented below. Changing this forces a new resource to be created.
    
      * `name` (`str`) - Specifies the name of the DevSpace Controller. Changing this forces a new resource to be created.
      * `tier` (`str`)
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    target_container_host_credentials_base64: pulumi.Output[str]
    """
    Base64 encoding of `kube_config_raw` of Azure Kubernetes Service cluster. Changing this forces a new resource to be created.
    """
    target_container_host_resource_id: pulumi.Output[str]
    """
    The resource id of Azure Kubernetes Service cluster. Changing this forces a new resource to be created.
    """
    def __init__(__self__, resource_name, opts=None, location=None, name=None, resource_group_name=None, sku=None, tags=None, target_container_host_credentials_base64=None, target_container_host_resource_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a DevSpace Controller.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] location: Specifies the supported location where the DevSpace Controller should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the DevSpace Controller. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group under which the DevSpace Controller resource has to be created. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] sku: A `sku` block as documented below. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] target_container_host_credentials_base64: Base64 encoding of `kube_config_raw` of Azure Kubernetes Service cluster. Changing this forces a new resource to be created.
        :param pulumi.Input[str] target_container_host_resource_id: The resource id of Azure Kubernetes Service cluster. Changing this forces a new resource to be created.
        
        The **sku** object supports the following:
        
          * `name` (`pulumi.Input[str]`) - Specifies the name of the DevSpace Controller. Changing this forces a new resource to be created.
          * `tier` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/devspace_controller.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['location'] = location
            __props__['name'] = name
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            if sku is None:
                raise TypeError("Missing required property 'sku'")
            __props__['sku'] = sku
            __props__['tags'] = tags
            if target_container_host_credentials_base64 is None:
                raise TypeError("Missing required property 'target_container_host_credentials_base64'")
            __props__['target_container_host_credentials_base64'] = target_container_host_credentials_base64
            if target_container_host_resource_id is None:
                raise TypeError("Missing required property 'target_container_host_resource_id'")
            __props__['target_container_host_resource_id'] = target_container_host_resource_id
            __props__['data_plane_fqdn'] = None
            __props__['host_suffix'] = None
        super(Controller, __self__).__init__(
            'azure:devspace/controller:Controller',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, data_plane_fqdn=None, host_suffix=None, location=None, name=None, resource_group_name=None, sku=None, tags=None, target_container_host_credentials_base64=None, target_container_host_resource_id=None):
        """
        Get an existing Controller resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] data_plane_fqdn: DNS name for accessing DataPlane services.
        :param pulumi.Input[str] host_suffix: The host suffix for the DevSpace Controller.
        :param pulumi.Input[str] location: Specifies the supported location where the DevSpace Controller should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the DevSpace Controller. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group under which the DevSpace Controller resource has to be created. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] sku: A `sku` block as documented below. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] target_container_host_credentials_base64: Base64 encoding of `kube_config_raw` of Azure Kubernetes Service cluster. Changing this forces a new resource to be created.
        :param pulumi.Input[str] target_container_host_resource_id: The resource id of Azure Kubernetes Service cluster. Changing this forces a new resource to be created.
        
        The **sku** object supports the following:
        
          * `name` (`pulumi.Input[str]`) - Specifies the name of the DevSpace Controller. Changing this forces a new resource to be created.
          * `tier` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/devspace_controller.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["data_plane_fqdn"] = data_plane_fqdn
        __props__["host_suffix"] = host_suffix
        __props__["location"] = location
        __props__["name"] = name
        __props__["resource_group_name"] = resource_group_name
        __props__["sku"] = sku
        __props__["tags"] = tags
        __props__["target_container_host_credentials_base64"] = target_container_host_credentials_base64
        __props__["target_container_host_resource_id"] = target_container_host_resource_id
        return Controller(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class AccessPolicy(pulumi.CustomResource):
    application_id: pulumi.Output[str]
    """
    The object ID of an Application in Azure Active Directory.
    """
    certificate_permissions: pulumi.Output[list]
    """
    List of certificate permissions, must be one or more from
    the following: `backup`, `create`, `delete`, `deleteissuers`, `get`, `getissuers`, `import`, `list`, `listissuers`,
    `managecontacts`, `manageissuers`, `purge`, `recover`, `restore`, `setissuers` and `update`.
    """
    key_permissions: pulumi.Output[list]
    """
    List of key permissions, must be one or more from
    the following: `backup`, `create`, `decrypt`, `delete`, `encrypt`, `get`, `import`, `list`, `purge`,
    `recover`, `restore`, `sign`, `unwrapKey`, `update`, `verify` and `wrapKey`.
    """
    key_vault_id: pulumi.Output[str]
    """
    Specifies the id of the Key Vault resource. Changing this
    forces a new resource to be created.
    """
    object_id: pulumi.Output[str]
    """
    The object ID of a user, service principal or security
    group in the Azure Active Directory tenant for the vault. The object ID must
    be unique for the list of access policies. Changing this forces a new resource
    to be created.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group in which to
    create the namespace. Changing this forces a new resource to be created.
    """
    secret_permissions: pulumi.Output[list]
    """
    List of secret permissions, must be one or more
    from the following: `backup`, `delete`, `get`, `list`, `purge`, `recover`, `restore` and `set`.
    """
    storage_permissions: pulumi.Output[list]
    """
    List of storage permissions, must be one or more from the following: `backup`, `delete`, `deletesas`, `get`, `getsas`, `list`, `listsas`, `purge`, `recover`, `regeneratekey`, `restore`, `set`, `setsas` and `update`.
    """
    tenant_id: pulumi.Output[str]
    """
    The Azure Active Directory tenant ID that should be used
    for authenticating requests to the key vault. Changing this forces a new resource
    to be created.
    """
    vault_name: pulumi.Output[str]
    """
    Specifies the name of the Key Vault resource. Changing this
    forces a new resource to be created.
    """
    def __init__(__self__, resource_name, opts=None, application_id=None, certificate_permissions=None, key_permissions=None, key_vault_id=None, object_id=None, resource_group_name=None, secret_permissions=None, storage_permissions=None, tenant_id=None, vault_name=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a Key Vault Access Policy.
        
        > **NOTE:** It's possible to define Key Vault Access Policies both within the `keyvault.KeyVault` resource via the `access_policy` block and by using the `keyvault.AccessPolicy` resource. However it's not possible to use both methods to manage Access Policies within a KeyVault, since there'll be conflicts.
        
        > **NOTE:** Azure permits a maximum of 1024 Access Policies per Key Vault - [more information can be found in this document](https://docs.microsoft.com/en-us/azure/key-vault/key-vault-secure-your-key-vault#data-plane-access-control).
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_id: The object ID of an Application in Azure Active Directory.
        :param pulumi.Input[list] certificate_permissions: List of certificate permissions, must be one or more from
               the following: `backup`, `create`, `delete`, `deleteissuers`, `get`, `getissuers`, `import`, `list`, `listissuers`,
               `managecontacts`, `manageissuers`, `purge`, `recover`, `restore`, `setissuers` and `update`.
        :param pulumi.Input[list] key_permissions: List of key permissions, must be one or more from
               the following: `backup`, `create`, `decrypt`, `delete`, `encrypt`, `get`, `import`, `list`, `purge`,
               `recover`, `restore`, `sign`, `unwrapKey`, `update`, `verify` and `wrapKey`.
        :param pulumi.Input[str] key_vault_id: Specifies the id of the Key Vault resource. Changing this
               forces a new resource to be created.
        :param pulumi.Input[str] object_id: The object ID of a user, service principal or security
               group in the Azure Active Directory tenant for the vault. The object ID must
               be unique for the list of access policies. Changing this forces a new resource
               to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to
               create the namespace. Changing this forces a new resource to be created.
        :param pulumi.Input[list] secret_permissions: List of secret permissions, must be one or more
               from the following: `backup`, `delete`, `get`, `list`, `purge`, `recover`, `restore` and `set`.
        :param pulumi.Input[list] storage_permissions: List of storage permissions, must be one or more from the following: `backup`, `delete`, `deletesas`, `get`, `getsas`, `list`, `listsas`, `purge`, `recover`, `regeneratekey`, `restore`, `set`, `setsas` and `update`.
        :param pulumi.Input[str] tenant_id: The Azure Active Directory tenant ID that should be used
               for authenticating requests to the key vault. Changing this forces a new resource
               to be created.
        :param pulumi.Input[str] vault_name: Specifies the name of the Key Vault resource. Changing this
               forces a new resource to be created.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/key_vault_access_policy.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['application_id'] = application_id
            __props__['certificate_permissions'] = certificate_permissions
            __props__['key_permissions'] = key_permissions
            __props__['key_vault_id'] = key_vault_id
            if object_id is None:
                raise TypeError("Missing required property 'object_id'")
            __props__['object_id'] = object_id
            __props__['resource_group_name'] = resource_group_name
            __props__['secret_permissions'] = secret_permissions
            __props__['storage_permissions'] = storage_permissions
            if tenant_id is None:
                raise TypeError("Missing required property 'tenant_id'")
            __props__['tenant_id'] = tenant_id
            __props__['vault_name'] = vault_name
        super(AccessPolicy, __self__).__init__(
            'azure:keyvault/accessPolicy:AccessPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, application_id=None, certificate_permissions=None, key_permissions=None, key_vault_id=None, object_id=None, resource_group_name=None, secret_permissions=None, storage_permissions=None, tenant_id=None, vault_name=None):
        """
        Get an existing AccessPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_id: The object ID of an Application in Azure Active Directory.
        :param pulumi.Input[list] certificate_permissions: List of certificate permissions, must be one or more from
               the following: `backup`, `create`, `delete`, `deleteissuers`, `get`, `getissuers`, `import`, `list`, `listissuers`,
               `managecontacts`, `manageissuers`, `purge`, `recover`, `restore`, `setissuers` and `update`.
        :param pulumi.Input[list] key_permissions: List of key permissions, must be one or more from
               the following: `backup`, `create`, `decrypt`, `delete`, `encrypt`, `get`, `import`, `list`, `purge`,
               `recover`, `restore`, `sign`, `unwrapKey`, `update`, `verify` and `wrapKey`.
        :param pulumi.Input[str] key_vault_id: Specifies the id of the Key Vault resource. Changing this
               forces a new resource to be created.
        :param pulumi.Input[str] object_id: The object ID of a user, service principal or security
               group in the Azure Active Directory tenant for the vault. The object ID must
               be unique for the list of access policies. Changing this forces a new resource
               to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to
               create the namespace. Changing this forces a new resource to be created.
        :param pulumi.Input[list] secret_permissions: List of secret permissions, must be one or more
               from the following: `backup`, `delete`, `get`, `list`, `purge`, `recover`, `restore` and `set`.
        :param pulumi.Input[list] storage_permissions: List of storage permissions, must be one or more from the following: `backup`, `delete`, `deletesas`, `get`, `getsas`, `list`, `listsas`, `purge`, `recover`, `regeneratekey`, `restore`, `set`, `setsas` and `update`.
        :param pulumi.Input[str] tenant_id: The Azure Active Directory tenant ID that should be used
               for authenticating requests to the key vault. Changing this forces a new resource
               to be created.
        :param pulumi.Input[str] vault_name: Specifies the name of the Key Vault resource. Changing this
               forces a new resource to be created.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/key_vault_access_policy.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["application_id"] = application_id
        __props__["certificate_permissions"] = certificate_permissions
        __props__["key_permissions"] = key_permissions
        __props__["key_vault_id"] = key_vault_id
        __props__["object_id"] = object_id
        __props__["resource_group_name"] = resource_group_name
        __props__["secret_permissions"] = secret_permissions
        __props__["storage_permissions"] = storage_permissions
        __props__["tenant_id"] = tenant_id
        __props__["vault_name"] = vault_name
        return AccessPolicy(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class AutoscaleSetting(pulumi.CustomResource):
    enabled: pulumi.Output[bool]
    """
    Specifies whether automatic scaling is enabled for the target resource. Defaults to `true`.
    """
    location: pulumi.Output[str]
    """
    Specifies the supported Azure location where the AutoScale Setting should exist. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    The name of the AutoScale Setting. Changing this forces a new resource to be created.
    """
    notification: pulumi.Output[dict]
    """
    Specifies a `notification` block as defined below.
    
      * `email` (`dict`)
    
        * `customEmails` (`list`)
        * `sendToSubscriptionAdministrator` (`bool`)
        * `sendToSubscriptionCoAdministrator` (`bool`)
    
      * `webhooks` (`list`)
    
        * `properties` (`dict`)
        * `service_uri` (`str`)
    """
    profiles: pulumi.Output[list]
    """
    Specifies one or more (up to 20) `profile` blocks as defined below.
    
      * `capacity` (`dict`)
    
        * `default` (`float`)
        * `maximum` (`float`)
        * `minimum` (`float`)
    
      * `fixedDate` (`dict`)
    
        * `end` (`str`)
        * `start` (`str`)
        * `timezone` (`str`)
    
      * `name` (`str`) - The name of the AutoScale Setting. Changing this forces a new resource to be created.
      * `recurrence` (`dict`)
    
        * `days` (`list`)
        * `hours` (`float`)
        * `minutes` (`float`)
        * `timezone` (`str`)
    
      * `rules` (`list`)
    
        * `metricTrigger` (`dict`)
    
          * `metric_name` (`str`)
          * `metricResourceId` (`str`)
          * `operator` (`str`)
          * `statistic` (`str`)
          * `threshold` (`float`)
          * `timeAggregation` (`str`)
          * `timeGrain` (`str`)
          * `timeWindow` (`str`)
    
        * `scaleAction` (`dict`)
    
          * `cooldown` (`str`)
          * `direction` (`str`)
          * `type` (`str`)
          * `value` (`float`)
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the Resource Group in the AutoScale Setting should be created. Changing this forces a new resource to be created.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    target_resource_id: pulumi.Output[str]
    """
    Specifies the resource ID of the resource that the autoscale setting should be added to.
    """
    def __init__(__self__, resource_name, opts=None, enabled=None, location=None, name=None, notification=None, profiles=None, resource_group_name=None, tags=None, target_resource_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a AutoScale Setting which can be applied to Virtual Machine Scale Sets, App Services and other scalable resources.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enabled: Specifies whether automatic scaling is enabled for the target resource. Defaults to `true`.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the AutoScale Setting should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the AutoScale Setting. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] notification: Specifies a `notification` block as defined below.
        :param pulumi.Input[list] profiles: Specifies one or more (up to 20) `profile` blocks as defined below.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group in the AutoScale Setting should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] target_resource_id: Specifies the resource ID of the resource that the autoscale setting should be added to.
        
        The **notification** object supports the following:
        
          * `email` (`pulumi.Input[dict]`)
        
            * `customEmails` (`pulumi.Input[list]`)
            * `sendToSubscriptionAdministrator` (`pulumi.Input[bool]`)
            * `sendToSubscriptionCoAdministrator` (`pulumi.Input[bool]`)
        
          * `webhooks` (`pulumi.Input[list]`)
        
            * `properties` (`pulumi.Input[dict]`)
            * `service_uri` (`pulumi.Input[str]`)
        
        The **profiles** object supports the following:
        
          * `capacity` (`pulumi.Input[dict]`)
        
            * `default` (`pulumi.Input[float]`)
            * `maximum` (`pulumi.Input[float]`)
            * `minimum` (`pulumi.Input[float]`)
        
          * `fixedDate` (`pulumi.Input[dict]`)
        
            * `end` (`pulumi.Input[str]`)
            * `start` (`pulumi.Input[str]`)
            * `timezone` (`pulumi.Input[str]`)
        
          * `name` (`pulumi.Input[str]`) - The name of the AutoScale Setting. Changing this forces a new resource to be created.
          * `recurrence` (`pulumi.Input[dict]`)
        
            * `days` (`pulumi.Input[list]`)
            * `hours` (`pulumi.Input[float]`)
            * `minutes` (`pulumi.Input[float]`)
            * `timezone` (`pulumi.Input[str]`)
        
          * `rules` (`pulumi.Input[list]`)
        
            * `metricTrigger` (`pulumi.Input[dict]`)
        
              * `metric_name` (`pulumi.Input[str]`)
              * `metricResourceId` (`pulumi.Input[str]`)
              * `operator` (`pulumi.Input[str]`)
              * `statistic` (`pulumi.Input[str]`)
              * `threshold` (`pulumi.Input[float]`)
              * `timeAggregation` (`pulumi.Input[str]`)
              * `timeGrain` (`pulumi.Input[str]`)
              * `timeWindow` (`pulumi.Input[str]`)
        
            * `scaleAction` (`pulumi.Input[dict]`)
        
              * `cooldown` (`pulumi.Input[str]`)
              * `direction` (`pulumi.Input[str]`)
              * `type` (`pulumi.Input[str]`)
              * `value` (`pulumi.Input[float]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/monitor_autoscale_setting.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['enabled'] = enabled
            __props__['location'] = location
            __props__['name'] = name
            __props__['notification'] = notification
            if profiles is None:
                raise TypeError("Missing required property 'profiles'")
            __props__['profiles'] = profiles
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['tags'] = tags
            if target_resource_id is None:
                raise TypeError("Missing required property 'target_resource_id'")
            __props__['target_resource_id'] = target_resource_id
        super(AutoscaleSetting, __self__).__init__(
            'azure:monitoring/autoscaleSetting:AutoscaleSetting',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, enabled=None, location=None, name=None, notification=None, profiles=None, resource_group_name=None, tags=None, target_resource_id=None):
        """
        Get an existing AutoscaleSetting resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enabled: Specifies whether automatic scaling is enabled for the target resource. Defaults to `true`.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the AutoScale Setting should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the AutoScale Setting. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] notification: Specifies a `notification` block as defined below.
        :param pulumi.Input[list] profiles: Specifies one or more (up to 20) `profile` blocks as defined below.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group in the AutoScale Setting should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] target_resource_id: Specifies the resource ID of the resource that the autoscale setting should be added to.
        
        The **notification** object supports the following:
        
          * `email` (`pulumi.Input[dict]`)
        
            * `customEmails` (`pulumi.Input[list]`)
            * `sendToSubscriptionAdministrator` (`pulumi.Input[bool]`)
            * `sendToSubscriptionCoAdministrator` (`pulumi.Input[bool]`)
        
          * `webhooks` (`pulumi.Input[list]`)
        
            * `properties` (`pulumi.Input[dict]`)
            * `service_uri` (`pulumi.Input[str]`)
        
        The **profiles** object supports the following:
        
          * `capacity` (`pulumi.Input[dict]`)
        
            * `default` (`pulumi.Input[float]`)
            * `maximum` (`pulumi.Input[float]`)
            * `minimum` (`pulumi.Input[float]`)
        
          * `fixedDate` (`pulumi.Input[dict]`)
        
            * `end` (`pulumi.Input[str]`)
            * `start` (`pulumi.Input[str]`)
            * `timezone` (`pulumi.Input[str]`)
        
          * `name` (`pulumi.Input[str]`) - The name of the AutoScale Setting. Changing this forces a new resource to be created.
          * `recurrence` (`pulumi.Input[dict]`)
        
            * `days` (`pulumi.Input[list]`)
            * `hours` (`pulumi.Input[float]`)
            * `minutes` (`pulumi.Input[float]`)
            * `timezone` (`pulumi.Input[str]`)
        
          * `rules` (`pulumi.Input[list]`)
        
            * `metricTrigger` (`pulumi.Input[dict]`)
        
              * `metric_name` (`pulumi.Input[str]`)
              * `metricResourceId` (`pulumi.Input[str]`)
              * `operator` (`pulumi.Input[str]`)
              * `statistic` (`pulumi.Input[str]`)
              * `threshold` (`pulumi.Input[float]`)
              * `timeAggregation` (`pulumi.Input[str]`)
              * `timeGrain` (`pulumi.Input[str]`)
              * `timeWindow` (`pulumi.Input[str]`)
        
            * `scaleAction` (`pulumi.Input[dict]`)
        
              * `cooldown` (`pulumi.Input[str]`)
              * `direction` (`pulumi.Input[str]`)
              * `type` (`pulumi.Input[str]`)
              * `value` (`pulumi.Input[float]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/monitor_autoscale_setting.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["enabled"] = enabled
        __props__["location"] = location
        __props__["name"] = name
        __props__["notification"] = notification
        __props__["profiles"] = profiles
        __props__["resource_group_name"] = resource_group_name
        __props__["tags"] = tags
        __props__["target_resource_id"] = target_resource_id
        return AutoscaleSetting(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class EventHub(pulumi.CustomResource):
    capture_description: pulumi.Output[dict]
    """
    A `capture_description` block as defined below.
    
      * `destination` (`dict`)
    
        * `archiveNameFormat` (`str`)
        * `blobContainerName` (`str`)
        * `name` (`str`) - Specifies the name of the EventHub Namespace resource. Changing this forces a new resource to be created.
        * `storage_account_id` (`str`)
    
      * `enabled` (`bool`)
      * `encoding` (`str`)
      * `intervalInSeconds` (`float`)
      * `sizeLimitInBytes` (`float`)
      * `skipEmptyArchives` (`bool`)
    """
    location: pulumi.Output[str]
    message_retention: pulumi.Output[float]
    """
    Specifies the number of days to retain the events for this Event Hub. Needs to be between 1 and 7 days; or 1 day when using a Basic SKU for the parent EventHub Namespace.
    """
    name: pulumi.Output[str]
    """
    Specifies the name of the EventHub Namespace resource. Changing this forces a new resource to be created.
    """
    namespace_name: pulumi.Output[str]
    """
    Specifies the name of the EventHub Namespace. Changing this forces a new resource to be created.
    """
    partition_count: pulumi.Output[float]
    """
    Specifies the current number of shards on the Event Hub. Changing this forces a new resource to be created.
    """
    partition_ids: pulumi.Output[list]
    """
    The identifiers for partitions created for Event Hubs.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group in which the EventHub's parent Namespace exists. Changing this forces a new resource to be created.
    """
    def __init__(__self__, resource_name, opts=None, capture_description=None, location=None, message_retention=None, name=None, namespace_name=None, partition_count=None, resource_group_name=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a Event Hubs as a nested resource within a Event Hubs namespace.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] capture_description: A `capture_description` block as defined below.
        :param pulumi.Input[float] message_retention: Specifies the number of days to retain the events for this Event Hub. Needs to be between 1 and 7 days; or 1 day when using a Basic SKU for the parent EventHub Namespace.
        :param pulumi.Input[str] name: Specifies the name of the EventHub Namespace resource. Changing this forces a new resource to be created.
        :param pulumi.Input[str] namespace_name: Specifies the name of the EventHub Namespace. Changing this forces a new resource to be created.
        :param pulumi.Input[float] partition_count: Specifies the current number of shards on the Event Hub. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the EventHub's parent Namespace exists. Changing this forces a new resource to be created.
        
        The **capture_description** object supports the following:
        
          * `destination` (`pulumi.Input[dict]`)
        
            * `archiveNameFormat` (`pulumi.Input[str]`)
            * `blobContainerName` (`pulumi.Input[str]`)
            * `name` (`pulumi.Input[str]`) - Specifies the name of the EventHub Namespace resource. Changing this forces a new resource to be created.
            * `storage_account_id` (`pulumi.Input[str]`)
        
          * `enabled` (`pulumi.Input[bool]`)
          * `encoding` (`pulumi.Input[str]`)
          * `intervalInSeconds` (`pulumi.Input[float]`)
          * `sizeLimitInBytes` (`pulumi.Input[float]`)
          * `skipEmptyArchives` (`pulumi.Input[bool]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/eventhub.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['capture_description'] = capture_description
            __props__['location'] = location
            if message_retention is None:
                raise TypeError("Missing required property 'message_retention'")
            __props__['message_retention'] = message_retention
            __props__['name'] = name
            if namespace_name is None:
                raise TypeError("Missing required property 'namespace_name'")
            __props__['namespace_name'] = namespace_name
            if partition_count is None:
                raise TypeError("Missing required property 'partition_count'")
            __props__['partition_count'] = partition_count
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['partition_ids'] = None
        super(EventHub, __self__).__init__(
            'azure:eventhub/eventHub:EventHub',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, capture_description=None, location=None, message_retention=None, name=None, namespace_name=None, partition_count=None, partition_ids=None, resource_group_name=None):
        """
        Get an existing EventHub resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] capture_description: A `capture_description` block as defined below.
        :param pulumi.Input[float] message_retention: Specifies the number of days to retain the events for this Event Hub. Needs to be between 1 and 7 days; or 1 day when using a Basic SKU for the parent EventHub Namespace.
        :param pulumi.Input[str] name: Specifies the name of the EventHub Namespace resource. Changing this forces a new resource to be created.
        :param pulumi.Input[str] namespace_name: Specifies the name of the EventHub Namespace. Changing this forces a new resource to be created.
        :param pulumi.Input[float] partition_count: Specifies the current number of shards on the Event Hub. Changing this forces a new resource to be created.
        :param pulumi.Input[list] partition_ids: The identifiers for partitions created for Event Hubs.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which the EventHub's parent Namespace exists. Changing this forces a new resource to be created.
        
        The **capture_description** object supports the following:
        
          * `destination` (`pulumi.Input[dict]`)
        
            * `archiveNameFormat` (`pulumi.Input[str]`)
            * `blobContainerName` (`pulumi.Input[str]`)
            * `name` (`pulumi.Input[str]`) - Specifies the name of the EventHub Namespace resource. Changing this forces a new resource to be created.
            * `storage_account_id` (`pulumi.Input[str]`)
        
          * `enabled` (`pulumi.Input[bool]`)
          * `encoding` (`pulumi.Input[str]`)
          * `intervalInSeconds` (`pulumi.Input[float]`)
          * `sizeLimitInBytes` (`pulumi.Input[float]`)
          * `skipEmptyArchives` (`pulumi.Input[bool]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/eventhub.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["capture_description"] = capture_description
        __props__["location"] = location
        __props__["message_retention"] = message_retention
        __props__["name"] = name
        __props__["namespace_name"] = namespace_name
        __props__["partition_count"] = partition_count
        __props__["partition_ids"] = partition_ids
        __props__["resource_group_name"] = resource_group_name
        return EventHub(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class KubernetesCluster(pulumi.CustomResource):
    addon_profile: pulumi.Output[dict]
    agent_pool_profiles: pulumi.Output[list]
    """
    One or more `agent_pool_profile` blocks as defined below.
    
      * `availability_zones` (`list`)
      * `count` (`float`)
      * `dns_prefix` (`str`) - DNS prefix specified when creating the managed cluster. Changing this forces a new resource to be created.
      * `enable_auto_scaling` (`bool`)
      * `enable_node_public_ip` (`bool`)
      * `fqdn` (`str`) - The FQDN of the Azure Kubernetes Managed Cluster.
      * `max_count` (`float`)
      * `max_pods` (`float`)
      * `min_count` (`float`)
      * `name` (`str`) - The name of the Managed Kubernetes Cluster to create. Changing this forces a new resource to be created.
      * `node_taints` (`list`)
      * `os_disk_size_gb` (`float`)
      * `os_type` (`str`)
      * `type` (`str`)
      * `vm_size` (`str`)
      * `vnet_subnet_id` (`str`)
    """
    api_server_authorized_ip_ranges: pulumi.Output[list]
    default_node_pool: pulumi.Output[dict]
    """
    A `default_node_pool` block as defined below.
    
      * `availability_zones` (`list`)
      * `enable_auto_scaling` (`bool`)
      * `enable_node_public_ip` (`bool`)
      * `max_count` (`float`)
      * `max_pods` (`float`)
      * `min_count` (`float`)
      * `name` (`str`) - The name of the Managed Kubernetes Cluster to create. Changing this forces a new resource to be created.
      * `node_count` (`float`)
      * `node_taints` (`list`)
      * `os_disk_size_gb` (`float`)
      * `type` (`str`)
      * `vm_size` (`str`)
      * `vnet_subnet_id` (`str`)
    """
    dns_prefix: pulumi.Output[str]
    """
    DNS prefix specified when creating the managed cluster. Changing this forces a new resource to be created.
    """
    enable_pod_security_policy: pulumi.Output[bool]
    fqdn: pulumi.Output[str]
    """
    The FQDN of the Azure Kubernetes Managed Cluster.
    """
    kube_admin_config: pulumi.Output[dict]
    """
    A `kube_admin_config` block as defined below. This is only available when Role Based Access Control with Azure Active Directory is enabled.
    
      * `clientCertificate` (`str`) - Base64 encoded public certificate used by clients to authenticate to the Kubernetes cluster.
      * `clientKey` (`str`) - Base64 encoded private key used by clients to authenticate to the Kubernetes cluster.
      * `clusterCaCertificate` (`str`) - Base64 encoded public CA certificate used as the root of trust for the Kubernetes cluster.
      * `host` (`str`) - The Kubernetes cluster server host.
      * `password` (`str`) - A password or token used to authenticate to the Kubernetes cluster.
      * `username` (`str`) - A username used to authenticate to the Kubernetes cluster.
    """
    kube_admin_config_raw: pulumi.Output[str]
    """
    Raw Kubernetes config for the admin account to be used by [kubectl](https://kubernetes.io/docs/reference/kubectl/overview/) and other compatible tools. This is only available when Role Based Access Control with Azure Active Directory is enabled.
    """
    kube_config: pulumi.Output[dict]
    """
    A `kube_config` block as defined below.
    
      * `clientCertificate` (`str`) - Base64 encoded public certificate used by clients to authenticate to the Kubernetes cluster.
      * `clientKey` (`str`) - Base64 encoded private key used by clients to authenticate to the Kubernetes cluster.
      * `clusterCaCertificate` (`str`) - Base64 encoded public CA certificate used as the root of trust for the Kubernetes cluster.
      * `host` (`str`) - The Kubernetes cluster server host.
      * `password` (`str`) - A password or token used to authenticate to the Kubernetes cluster.
      * `username` (`str`) - A username used to authenticate to the Kubernetes cluster.
    """
    kube_config_raw: pulumi.Output[str]
    """
    Raw Kubernetes config to be used by [kubectl](https://kubernetes.io/docs/reference/kubectl/overview/) and other compatible tools
    """
    kubernetes_version: pulumi.Output[str]
    linux_profile: pulumi.Output[dict]
    location: pulumi.Output[str]
    """
    The location where the Managed Kubernetes Cluster should be created. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    The name of the Managed Kubernetes Cluster to create. Changing this forces a new resource to be created.
    """
    network_profile: pulumi.Output[dict]
    node_resource_group: pulumi.Output[str]
    """
    The auto-generated Resource Group which contains the resources for this Managed Kubernetes Cluster.
    """
    resource_group_name: pulumi.Output[str]
    """
    Specifies the Resource Group where the Managed Kubernetes Cluster should exist. Changing this forces a new resource to be created.
    """
    role_based_access_control: pulumi.Output[dict]
    service_principal: pulumi.Output[dict]
    """
    A `service_principal` block as documented below.
    
      * `client_id` (`str`)
      * `client_secret` (`str`)
    """
    tags: pulumi.Output[dict]
    windows_profile: pulumi.Output[dict]
    def __init__(__self__, resource_name, opts=None, addon_profile=None, agent_pool_profiles=None, api_server_authorized_ip_ranges=None, default_node_pool=None, dns_prefix=None, enable_pod_security_policy=None, kubernetes_version=None, linux_profile=None, location=None, name=None, network_profile=None, node_resource_group=None, resource_group_name=None, role_based_access_control=None, service_principal=None, tags=None, windows_profile=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a Managed Kubernetes Cluster (also known as AKS / Azure Kubernetes Service)
        
        > **Note:** All arguments including the client secret will be stored in the raw state as plain-text. [Read more about sensitive data in state](https://www.terraform.io/docs/state/sensitive-data.html).
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] agent_pool_profiles: One or more `agent_pool_profile` blocks as defined below.
        :param pulumi.Input[dict] default_node_pool: A `default_node_pool` block as defined below.
        :param pulumi.Input[str] dns_prefix: DNS prefix specified when creating the managed cluster. Changing this forces a new resource to be created.
        :param pulumi.Input[str] location: The location where the Managed Kubernetes Cluster should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the Managed Kubernetes Cluster to create. Changing this forces a new resource to be created.
        :param pulumi.Input[str] node_resource_group: The auto-generated Resource Group which contains the resources for this Managed Kubernetes Cluster.
        :param pulumi.Input[str] resource_group_name: Specifies the Resource Group where the Managed Kubernetes Cluster should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] service_principal: A `service_principal` block as documented below.
        
        The **addon_profile** object supports the following:
        
          * `aciConnectorLinux` (`pulumi.Input[dict]`)
        
            * `enabled` (`pulumi.Input[bool]`)
            * `subnetName` (`pulumi.Input[str]`)
        
          * `azurePolicy` (`pulumi.Input[dict]`)
        
            * `enabled` (`pulumi.Input[bool]`)
        
          * `httpApplicationRouting` (`pulumi.Input[dict]`) - A `http_application_routing` block as defined below.
        
            * `enabled` (`pulumi.Input[bool]`)
            * `httpApplicationRoutingZoneName` (`pulumi.Input[str]`) - The Zone Name of the HTTP Application Routing.
        
          * `kubeDashboard` (`pulumi.Input[dict]`)
        
            * `enabled` (`pulumi.Input[bool]`)
        
          * `omsAgent` (`pulumi.Input[dict]`)
        
            * `enabled` (`pulumi.Input[bool]`)
            * `logAnalyticsWorkspaceId` (`pulumi.Input[str]`)
        
        The **agent_pool_profiles** object supports the following:
        
          * `availability_zones` (`pulumi.Input[list]`)
          * `count` (`pulumi.Input[float]`)
          * `dns_prefix` (`pulumi.Input[str]`) - DNS prefix specified when creating the managed cluster. Changing this forces a new resource to be created.
          * `enable_auto_scaling` (`pulumi.Input[bool]`)
          * `enable_node_public_ip` (`pulumi.Input[bool]`)
          * `fqdn` (`pulumi.Input[str]`) - The FQDN of the Azure Kubernetes Managed Cluster.
          * `max_count` (`pulumi.Input[float]`)
          * `max_pods` (`pulumi.Input[float]`)
          * `min_count` (`pulumi.Input[float]`)
          * `name` (`pulumi.Input[str]`) - The name of the Managed Kubernetes Cluster to create. Changing this forces a new resource to be created.
          * `node_taints` (`pulumi.Input[list]`)
          * `os_disk_size_gb` (`pulumi.Input[float]`)
          * `os_type` (`pulumi.Input[str]`)
          * `type` (`pulumi.Input[str]`)
          * `vm_size` (`pulumi.Input[str]`)
          * `vnet_subnet_id` (`pulumi.Input[str]`)
        
        The **default_node_pool** object supports the following:
        
          * `availability_zones` (`pulumi.Input[list]`)
          * `enable_auto_scaling` (`pulumi.Input[bool]`)
          * `enable_node_public_ip` (`pulumi.Input[bool]`)
          * `max_count` (`pulumi.Input[float]`)
          * `max_pods` (`pulumi.Input[float]`)
          * `min_count` (`pulumi.Input[float]`)
          * `name` (`pulumi.Input[str]`) - The name of the Managed Kubernetes Cluster to create. Changing this forces a new resource to be created.
          * `node_count` (`pulumi.Input[float]`)
          * `node_taints` (`pulumi.Input[list]`)
          * `os_disk_size_gb` (`pulumi.Input[float]`)
          * `type` (`pulumi.Input[str]`)
          * `vm_size` (`pulumi.Input[str]`)
          * `vnet_subnet_id` (`pulumi.Input[str]`)
        
        The **linux_profile** object supports the following:
        
          * `admin_username` (`pulumi.Input[str]`)
          * `sshKey` (`pulumi.Input[dict]`)
        
            * `keyData` (`pulumi.Input[str]`)
        
        The **network_profile** object supports the following:
        
          * `dnsServiceIp` (`pulumi.Input[str]`)
          * `dockerBridgeCidr` (`pulumi.Input[str]`)
          * `loadBalancerSku` (`pulumi.Input[str]`)
          * `networkPlugin` (`pulumi.Input[str]`)
          * `networkPolicy` (`pulumi.Input[str]`)
          * `podCidr` (`pulumi.Input[str]`)
          * `serviceCidr` (`pulumi.Input[str]`)
        
        The **role_based_access_control** object supports the following:
        
          * `azureActiveDirectory` (`pulumi.Input[dict]`)
        
            * `clientAppId` (`pulumi.Input[str]`)
            * `serverAppId` (`pulumi.Input[str]`)
            * `serverAppSecret` (`pulumi.Input[str]`)
            * `tenantId` (`pulumi.Input[str]`)
        
          * `enabled` (`pulumi.Input[bool]`)
        
        The **service_principal** object supports the following:
        
          * `client_id` (`pulumi.Input[str]`)
          * `client_secret` (`pulumi.Input[str]`)
        
        The **windows_profile** object supports the following:
        
          * `admin_password` (`pulumi.Input[str]`)
          * `admin_username` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/kubernetes_cluster.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['addon_profile'] = addon_profile
            __props__['agent_pool_profiles'] = agent_pool_profiles
            __props__['api_server_authorized_ip_ranges'] = api_server_authorized_ip_ranges
            __props__['default_node_pool'] = default_node_pool
            if dns_prefix is None:
                raise TypeError("Missing required property 'dns_prefix'")
            __props__['dns_prefix'] = dns_prefix
            __props__['enable_pod_security_policy'] = enable_pod_security_policy
            __props__['kubernetes_version'] = kubernetes_version
            __props__['linux_profile'] = linux_profile
            __props__['location'] = location
            __props__['name'] = name
            __props__['network_profile'] = network_profile
            __props__['node_resource_group'] = node_resource_group
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['role_based_access_control'] = role_based_access_control
            if service_principal is None:
                raise TypeError("Missing required property 'service_principal'")
            __props__['service_principal'] = service_principal
            __props__['tags'] = tags
            __props__['windows_profile'] = windows_profile
            __props__['fqdn'] = None
            __props__['kube_admin_config'] = None
            __props__['kube_admin_config_raw'] = None
            __props__['kube_config'] = None
            __props__['kube_config_raw'] = None
        super(KubernetesCluster, __self__).__init__(
            'azure:containerservice/kubernetesCluster:KubernetesCluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, addon_profile=None, agent_pool_profiles=None, api_server_authorized_ip_ranges=None, default_node_pool=None, dns_prefix=None, enable_pod_security_policy=None, fqdn=None, kube_admin_config=None, kube_admin_config_raw=None, kube_config=None, kube_config_raw=None, kubernetes_version=None, linux_profile=None, location=None, name=None, network_profile=None, node_resource_group=None, resource_group_name=None, role_based_access_control=None, service_principal=None, tags=None, windows_profile=None):
        """
        Get an existing KubernetesCluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] agent_pool_profiles: One or more `agent_pool_profile` blocks as defined below.
        :param pulumi.Input[dict] default_node_pool: A `default_node_pool` block as defined below.
        :param pulumi.Input[str] dns_prefix: DNS prefix specified when creating the managed cluster. Changing this forces a new resource to be created.
        :param pulumi.Input[str] fqdn: The FQDN of the Azure Kubernetes Managed Cluster.
        :param pulumi.Input[dict] kube_admin_config: A `kube_admin_config` block as defined below. This is only available when Role Based Access Control with Azure Active Directory is enabled.
        :param pulumi.Input[str] kube_admin_config_raw: Raw Kubernetes config for the admin account to be used by [kubectl](https://kubernetes.io/docs/reference/kubectl/overview/) and other compatible tools. This is only available when Role Based Access Control with Azure Active Directory is enabled.
        :param pulumi.Input[dict] kube_config: A `kube_config` block as defined below.
        :param pulumi.Input[str] kube_config_raw: Raw Kubernetes config to be used by [kubectl](https://kubernetes.io/docs/reference/kubectl/overview/) and other compatible tools
        :param pulumi.Input[str] location: The location where the Managed Kubernetes Cluster should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the Managed Kubernetes Cluster to create. Changing this forces a new resource to be created.
        :param pulumi.Input[str] node_resource_group: The auto-generated Resource Group which contains the resources for this Managed Kubernetes Cluster.
        :param pulumi.Input[str] resource_group_name: Specifies the Resource Group where the Managed Kubernetes Cluster should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] service_principal: A `service_principal` block as documented below.
        
        The **addon_profile** object supports the following:
        
          * `aciConnectorLinux` (`pulumi.Input[dict]`)
        
            * `enabled` (`pulumi.Input[bool]`)
            * `subnetName` (`pulumi.Input[str]`)
        
          * `azurePolicy` (`pulumi.Input[dict]`)
        
            * `enabled` (`pulumi.Input[bool]`)
        
          * `httpApplicationRouting` (`pulumi.Input[dict]`) - A `http_application_routing` block as defined below.
        
            * `enabled` (`pulumi.Input[bool]`)
            * `httpApplicationRoutingZoneName` (`pulumi.Input[str]`) - The Zone Name of the HTTP Application Routing.
        
          * `kubeDashboard` (`pulumi.Input[dict]`)
        
            * `enabled` (`pulumi.Input[bool]`)
        
          * `omsAgent` (`pulumi.Input[dict]`)
        
            * `enabled` (`pulumi.Input[bool]`)
            * `logAnalyticsWorkspaceId` (`pulumi.Input[str]`)
        
        The **agent_pool_profiles** object supports the following:
        
          * `availability_zones` (`pulumi.Input[list]`)
          * `count` (`pulumi.Input[float]`)
          * `dns_prefix` (`pulumi.Input[str]`) - DNS prefix specified when creating the managed cluster. Changing this forces a new resource to be created.
          * `enable_auto_scaling` (`pulumi.Input[bool]`)
          * `enable_node_public_ip` (`pulumi.Input[bool]`)
          * `fqdn` (`pulumi.Input[str]`) - The FQDN of the Azure Kubernetes Managed Cluster.
          * `max_count` (`pulumi.Input[float]`)
          * `max_pods` (`pulumi.Input[float]`)
          * `min_count` (`pulumi.Input[float]`)
          * `name` (`pulumi.Input[str]`) - The name of the Managed Kubernetes Cluster to create. Changing this forces a new resource to be created.
          * `node_taints` (`pulumi.Input[list]`)
          * `os_disk_size_gb` (`pulumi.Input[float]`)
          * `os_type` (`pulumi.Input[str]`)
          * `type` (`pulumi.Input[str]`)
          * `vm_size` (`pulumi.Input[str]`)
          * `vnet_subnet_id` (`pulumi.Input[str]`)
        
        The **default_node_pool** object supports the following:
        
          * `availability_zones` (`pulumi.Input[list]`)
          * `enable_auto_scaling` (`pulumi.Input[bool]`)
          * `enable_node_public_ip` (`pulumi.Input[bool]`)
          * `max_count` (`pulumi.Input[float]`)
          * `max_pods` (`pulumi.Input[float]`)
          * `min_count` (`pulumi.Input[float]`)
          * `name` (`pulumi.Input[str]`) - The name of the Managed Kubernetes Cluster to create. Changing this forces a new resource to be created.
          * `node_count` (`pulumi.Input[float]`)
          * `node_taints` (`pulumi.Input[list]`)
          * `os_disk_size_gb` (`pulumi.Input[float]`)
          * `type` (`pulumi.Input[str]`)
          * `vm_size` (`pulumi.Input[str]`)
          * `vnet_subnet_id` (`pulumi.Input[str]`)
        
        The **kube_admin_config** object supports the following:
        
          * `clientCertificate` (`pulumi.Input[str]`) - Base64 encoded public certificate used by clients to authenticate to the Kubernetes cluster.
          * `clientKey` (`pulumi.Input[str]`) - Base64 encoded private key used by clients to authenticate to the Kubernetes cluster.
          * `clusterCaCertificate` (`pulumi.Input[str]`) - Base64 encoded public CA certificate used as the root of trust for the Kubernetes cluster.
          * `host` (`pulumi.Input[str]`) - The Kubernetes cluster server host.
          * `password` (`pulumi.Input[str]`) - A password or token used to authenticate to the Kubernetes cluster.
          * `username` (`pulumi.Input[str]`) - A username used to authenticate to the Kubernetes cluster.
        
        The **kube_config** object supports the following:
        
          * `clientCertificate` (`pulumi.Input[str]`) - Base64 encoded public certificate used by clients to authenticate to the Kubernetes cluster.
          * `clientKey` (`pulumi.Input[str]`) - Base64 encoded private key used by clients to authenticate to the Kubernetes cluster.
          * `clusterCaCertificate` (`pulumi.Input[str]`) - Base64 encoded public CA certificate used as the root of trust for the Kubernetes cluster.
          * `host` (`pulumi.Input[str]`) - The Kubernetes cluster server host.
          * `password` (`pulumi.Input[str]`) - A password or token used to authenticate to the Kubernetes cluster.
          * `username` (`pulumi.Input[str]`) - A username used to authenticate to the Kubernetes cluster.
        
        The **linux_profile** object supports the following:
        
          * `admin_username` (`pulumi.Input[str]`)
          * `sshKey` (`pulumi.Input[dict]`)
        
            * `keyData` (`pulumi.Input[str]`)
        
        The **network_profile** object supports the following:
        
          * `dnsServiceIp` (`pulumi.Input[str]`)
          * `dockerBridgeCidr` (`pulumi.Input[str]`)
          * `loadBalancerSku` (`pulumi.Input[str]`)
          * `networkPlugin` (`pulumi.Input[str]`)
          * `networkPolicy` (`pulumi.Input[str]`)
          * `podCidr` (`pulumi.Input[str]`)
          * `serviceCidr` (`pulumi.Input[str]`)
        
        The **role_based_access_control** object supports the following:
        
          * `azureActiveDirectory` (`pulumi.Input[dict]`)
        
            * `clientAppId` (`pulumi.Input[str]`)
            * `serverAppId` (`pulumi.Input[str]`)
            * `serverAppSecret` (`pulumi.Input[str]`)
            * `tenantId` (`pulumi.Input[str]`)
        
          * `enabled` (`pulumi.Input[bool]`)
        
        The **service_principal** object supports the following:
        
          * `client_id` (`pulumi.Input[str]`)
          * `client_secret` (`pulumi.Input[str]`)
        
        The **windows_profile** object supports the following:
        
          * `admin_password` (`pulumi.Input[str]`)
          * `admin_username` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/kubernetes_cluster.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["addon_profile"] = addon_profile
        __props__["agent_pool_profiles"] = agent_pool_profiles
        __props__["api_server_authorized_ip_ranges"] = api_server_authorized_ip_ranges
        __props__["default_node_pool"] = default_node_pool
        __props__["dns_prefix"] = dns_prefix
        __props__["enable_pod_security_policy"] = enable_pod_security_policy
        __props__["fqdn"] = fqdn
        __props__["kube_admin_config"] = kube_admin_config
        __props__["kube_admin_config_raw"] = kube_admin_config_raw
        __props__["kube_config"] = kube_config
        __props__["kube_config_raw"] = kube_config_raw
        __props__["kubernetes_version"] = kubernetes_version
        __props__["linux_profile"] = linux_profile
        __props__["location"] = location
        __props__["name"] = name
        __props__["network_profile"] = network_profile
        __props__["node_resource_group"] = node_resource_group
        __props__["resource_group_name"] = resource_group_name
        __props__["role_based_access_control"] = role_based_access_control
        __props__["service_principal"] = service_principal
        __props__["tags"] = tags
        __props__["windows_profile"] = windows_profile
        return KubernetesCluster(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetGroupResult:
    """
    A collection of values returned by getGroup.
    """
    def __init__(__self__, display_name=None, group_id=None, parent_management_group_id=None, subscription_ids=None, id=None):
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        __self__.display_name = display_name
        """
        A friendly name for the Management Group.
        """
        if group_id and not isinstance(group_id, str):
            raise TypeError("Expected argument 'group_id' to be a str")
        __self__.group_id = group_id
        if parent_management_group_id and not isinstance(parent_management_group_id, str):
            raise TypeError("Expected argument 'parent_management_group_id' to be a str")
        __self__.parent_management_group_id = parent_management_group_id
        """
        The ID of any Parent Management Group.
        """
        if subscription_ids and not isinstance(subscription_ids, list):
            raise TypeError("Expected argument 'subscription_ids' to be a list")
        __self__.subscription_ids = subscription_ids
        """
        A list of Subscription ID's which are assigned to the Management Group.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetGroupResult(GetGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupResult(
            display_name=self.display_name,
            group_id=self.group_id,
            parent_management_group_id=self.parent_management_group_id,
            subscription_ids=self.subscription_ids,
            id=self.id)

def get_group(group_id=None,opts=None):
    """
    Use this data source to access information about an existing Management Group.
    
    :param str group_id: Specifies the UUID of this Management Group.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/d/management_group.html.markdown.
    """
    __args__ = dict()

    __args__['groupId'] = group_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure:management/getGroup:getGroup', __args__, opts=opts).value

    return AwaitableGetGroupResult(
        display_name=__ret__.get('displayName'),
        group_id=__ret__.get('groupId'),
        parent_management_group_id=__ret__.get('parentManagementGroupId'),
        subscription_ids=__ret__.get('subscriptionIds'),
        id=__ret__.get('id'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Route(pulumi.CustomResource):
    condition: pulumi.Output[str]
    """
    The condition that is evaluated to apply the routing rule. If no condition is provided, it evaluates to `true` by default. For grammar, see: https://docs.microsoft.com/azure/iot-hub/iot-hub-devguide-query-language.
    """
    enabled: pulumi.Output[bool]
    """
    Specifies whether a route is enabled.
    """
    endpoint_names: pulumi.Output[str]
    """
    The list of endpoints to which messages that satisfy the condition are routed. Currently only one endpoint is allowed.
    """
    iothub_name: pulumi.Output[str]
    """
    The name of the IoTHub to which this Route belongs. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    The name of the route.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group under which the IotHub Route resource has to be created. Changing this forces a new resource to be created.
    """
    source: pulumi.Output[str]
    """
    The source that the routing rule is to be applied to. Possible values include: `DeviceJobLifecycleEvents`, `DeviceLifecycleEvents`, `DeviceMessages`, `Invalid`, `TwinChangeEvents`.
    """
    def __init__(__self__, resource_name, opts=None, condition=None, enabled=None, endpoint_names=None, iothub_name=None, name=None, resource_group_name=None, source=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages an IotHub Route
        
        > **NOTE:** Routes can be defined either directly on the `iot.IoTHub` resource, or using the `iot.Route` resourcs - but the two cannot be used together. If both are used against the same IoTHub, spurious changes will occur.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] condition: The condition that is evaluated to apply the routing rule. If no condition is provided, it evaluates to `true` by default. For grammar, see: https://docs.microsoft.com/azure/iot-hub/iot-hub-devguide-query-language.
        :param pulumi.Input[bool] enabled: Specifies whether a route is enabled.
        :param pulumi.Input[str] endpoint_names: The list of endpoints to which messages that satisfy the condition are routed. Currently only one endpoint is allowed.
        :param pulumi.Input[str] iothub_name: The name of the IoTHub to which this Route belongs. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the route.
        :param pulumi.Input[str] resource_group_name: The name of the resource group under which the IotHub Route resource has to be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] source: The source that the routing rule is to be applied to. Possible values include: `DeviceJobLifecycleEvents`, `DeviceLifecycleEvents`, `DeviceMessages`, `Invalid`, `TwinChangeEvents`.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/iothub_route.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['condition'] = condition
            if enabled is None:
                raise TypeError("Missing required property 'enabled'")
            __props__['enabled'] = enabled
            if endpoint_names is None:
                raise TypeError("Missing required property 'endpoint_names'")
            __props__['endpoint_names'] = endpoint_names
            if iothub_name is None:
                raise TypeError("Missing required property 'iothub_name'")
            __props__['iothub_name'] = iothub_name
            __props__['name'] = name
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            if source is None:
                raise TypeError("Missing required property 'source'")
            __props__['source'] = source
        super(Route, __self__).__init__(
            'azure:iot/route:Route',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, condition=None, enabled=None, endpoint_names=None, iothub_name=None, name=None, resource_group_name=None, source=None):
        """
        Get an existing Route resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] condition: The condition that is evaluated to apply the routing rule. If no condition is provided, it evaluates to `true` by default. For grammar, see: https://docs.microsoft.com/azure/iot-hub/iot-hub-devguide-query-language.
        :param pulumi.Input[bool] enabled: Specifies whether a route is enabled.
        :param pulumi.Input[str] endpoint_names: The list of endpoints to which messages that satisfy the condition are routed. Currently only one endpoint is allowed.
        :param pulumi.Input[str] iothub_name: The name of the IoTHub to which this Route belongs. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the route.
        :param pulumi.Input[str] resource_group_name: The name of the resource group under which the IotHub Route resource has to be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] source: The source that the routing rule is to be applied to. Possible values include: `DeviceJobLifecycleEvents`, `DeviceLifecycleEvents`, `DeviceMessages`, `Invalid`, `TwinChangeEvents`.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/iothub_route.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["condition"] = condition
        __props__["enabled"] = enabled
        __props__["endpoint_names"] = endpoint_names
        __props__["iothub_name"] = iothub_name
        __props__["name"] = name
        __props__["resource_group_name"] = resource_group_name
        __props__["source"] = source
        return Route(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetNetworkInterfaceResult:
    """
    A collection of values returned by getNetworkInterface.
    """
    def __init__(__self__, applied_dns_servers=None, dns_servers=None, enable_accelerated_networking=None, enable_ip_forwarding=None, internal_dns_name_label=None, internal_fqdn=None, ip_configurations=None, location=None, mac_address=None, name=None, network_security_group_id=None, private_ip_address=None, private_ip_addresses=None, resource_group_name=None, tags=None, virtual_machine_id=None, id=None):
        if applied_dns_servers and not isinstance(applied_dns_servers, list):
            raise TypeError("Expected argument 'applied_dns_servers' to be a list")
        __self__.applied_dns_servers = applied_dns_servers
        """
        List of DNS servers applied to the specified Network Interface.
        """
        if dns_servers and not isinstance(dns_servers, list):
            raise TypeError("Expected argument 'dns_servers' to be a list")
        __self__.dns_servers = dns_servers
        """
        The list of DNS servers used by the specified Network Interface.
        """
        if enable_accelerated_networking and not isinstance(enable_accelerated_networking, bool):
            raise TypeError("Expected argument 'enable_accelerated_networking' to be a bool")
        __self__.enable_accelerated_networking = enable_accelerated_networking
        """
        Indicates if accelerated networking is set on the specified Network Interface.
        """
        if enable_ip_forwarding and not isinstance(enable_ip_forwarding, bool):
            raise TypeError("Expected argument 'enable_ip_forwarding' to be a bool")
        __self__.enable_ip_forwarding = enable_ip_forwarding
        """
        Indicate if IP forwarding is set on the specified Network Interface.
        """
        if internal_dns_name_label and not isinstance(internal_dns_name_label, str):
            raise TypeError("Expected argument 'internal_dns_name_label' to be a str")
        __self__.internal_dns_name_label = internal_dns_name_label
        """
        The internal dns name label of the specified Network Interface.
        """
        if internal_fqdn and not isinstance(internal_fqdn, str):
            raise TypeError("Expected argument 'internal_fqdn' to be a str")
        __self__.internal_fqdn = internal_fqdn
        if ip_configurations and not isinstance(ip_configurations, list):
            raise TypeError("Expected argument 'ip_configurations' to be a list")
        __self__.ip_configurations = ip_configurations
        """
        One or more `ip_configuration` blocks as defined below.
        """
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        __self__.location = location
        """
        The location of the specified Network Interface.
        """
        if mac_address and not isinstance(mac_address, str):
            raise TypeError("Expected argument 'mac_address' to be a str")
        __self__.mac_address = mac_address
        """
        The MAC address used by the specified Network Interface.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        """
        The name of the IP Configuration.
        """
        if network_security_group_id and not isinstance(network_security_group_id, str):
            raise TypeError("Expected argument 'network_security_group_id' to be a str")
        __self__.network_security_group_id = network_security_group_id
        """
        The ID of the network security group associated to the specified Network Interface.
        """
        if private_ip_address and not isinstance(private_ip_address, str):
            raise TypeError("Expected argument 'private_ip_address' to be a str")
        __self__.private_ip_address = private_ip_address
        """
        The Private IP Address assigned to this Network Interface.
        """
        if private_ip_addresses and not isinstance(private_ip_addresses, list):
            raise TypeError("Expected argument 'private_ip_addresses' to be a list")
        __self__.private_ip_addresses = private_ip_addresses
        """
        The list of private ip addresses associates to the specified Network Interface.
        """
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        __self__.resource_group_name = resource_group_name
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        __self__.tags = tags
        """
        List the tags associated to the specified Network Interface.
        """
        if virtual_machine_id and not isinstance(virtual_machine_id, str):
            raise TypeError("Expected argument 'virtual_machine_id' to be a str")
        __self__.virtual_machine_id = virtual_machine_id
        """
        The ID of the virtual machine that the specified Network Interface is attached to.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetNetworkInterfaceResult(GetNetworkInterfaceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkInterfaceResult(
            applied_dns_servers=self.applied_dns_servers,
            dns_servers=self.dns_servers,
            enable_accelerated_networking=self.enable_accelerated_networking,
            enable_ip_forwarding=self.enable_ip_forwarding,
            internal_dns_name_label=self.internal_dns_name_label,
            internal_fqdn=self.internal_fqdn,
            ip_configurations=self.ip_configurations,
            location=self.location,
            mac_address=self.mac_address,
            name=self.name,
            network_security_group_id=self.network_security_group_id,
            private_ip_address=self.private_ip_address,
            private_ip_addresses=self.private_ip_addresses,
            resource_group_name=self.resource_group_name,
            tags=self.tags,
            virtual_machine_id=self.virtual_machine_id,
            id=self.id)

def get_network_interface(name=None,resource_group_name=None,opts=None):
    """
    Use this data source to access information about an existing Network Interface.
    
    :param str name: Specifies the name of the Network Interface.
    :param str resource_group_name: Specifies the name of the resource group the Network Interface is located in.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/d/network_interface.html.markdown.
    """
    __args__ = dict()

    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure:network/getNetworkInterface:getNetworkInterface', __args__, opts=opts).value

    return AwaitableGetNetworkInterfaceResult(
        applied_dns_servers=__ret__.get('appliedDnsServers'),
        dns_servers=__ret__.get('dnsServers'),
        enable_accelerated_networking=__ret__.get('enableAcceleratedNetworking'),
        enable_ip_forwarding=__ret__.get('enableIpForwarding'),
        internal_dns_name_label=__ret__.get('internalDnsNameLabel'),
        internal_fqdn=__ret__.get('internalFqdn'),
        ip_configurations=__ret__.get('ipConfigurations'),
        location=__ret__.get('location'),
        mac_address=__ret__.get('macAddress'),
        name=__ret__.get('name'),
        network_security_group_id=__ret__.get('networkSecurityGroupId'),
        private_ip_address=__ret__.get('privateIpAddress'),
        private_ip_addresses=__ret__.get('privateIpAddresses'),
        resource_group_name=__ret__.get('resourceGroupName'),
        tags=__ret__.get('tags'),
        virtual_machine_id=__ret__.get('virtualMachineId'),
        id=__ret__.get('id'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class ARecord(pulumi.CustomResource):
    name: pulumi.Output[str]
    """
    The name of the DNS A Record.
    """
    records: pulumi.Output[list]
    """
    List of IPv4 Addresses.
    """
    resource_group_name: pulumi.Output[str]
    """
    Specifies the resource group where the DNS Zone (parent resource) exists. Changing this forces a new resource to be created.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    ttl: pulumi.Output[float]
    zone_name: pulumi.Output[str]
    """
    Specifies the DNS Zone where the resource exists. Changing this forces a new resource to be created.
    """
    def __init__(__self__, resource_name, opts=None, name=None, records=None, resource_group_name=None, tags=None, ttl=None, zone_name=None, __props__=None, __name__=None, __opts__=None):
        """
        Enables you to manage DNS A Records within Azure DNS.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the DNS A Record.
        :param pulumi.Input[list] records: List of IPv4 Addresses.
        :param pulumi.Input[str] resource_group_name: Specifies the resource group where the DNS Zone (parent resource) exists. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] zone_name: Specifies the DNS Zone where the resource exists. Changing this forces a new resource to be created.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/dns_a_record.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['name'] = name
            if records is None:
                raise TypeError("Missing required property 'records'")
            __props__['records'] = records
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['tags'] = tags
            if ttl is None:
                raise TypeError("Missing required property 'ttl'")
            __props__['ttl'] = ttl
            if zone_name is None:
                raise TypeError("Missing required property 'zone_name'")
            __props__['zone_name'] = zone_name
        super(ARecord, __self__).__init__(
            'azure:dns/aRecord:ARecord',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, name=None, records=None, resource_group_name=None, tags=None, ttl=None, zone_name=None):
        """
        Get an existing ARecord resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the DNS A Record.
        :param pulumi.Input[list] records: List of IPv4 Addresses.
        :param pulumi.Input[str] resource_group_name: Specifies the resource group where the DNS Zone (parent resource) exists. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] zone_name: Specifies the DNS Zone where the resource exists. Changing this forces a new resource to be created.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/dns_a_record.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["name"] = name
        __props__["records"] = records
        __props__["resource_group_name"] = resource_group_name
        __props__["tags"] = tags
        __props__["ttl"] = ttl
        __props__["zone_name"] = zone_name
        return ARecord(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetKubernetesClusterResult:
    """
    A collection of values returned by getKubernetesCluster.
    """
    def __init__(__self__, addon_profiles=None, agent_pool_profiles=None, dns_prefix=None, fqdn=None, kube_admin_configs=None, kube_admin_config_raw=None, kube_configs=None, kube_config_raw=None, kubernetes_version=None, linux_profiles=None, location=None, name=None, network_profiles=None, node_resource_group=None, resource_group_name=None, role_based_access_controls=None, service_principals=None, tags=None, windows_profiles=None, id=None):
        if addon_profiles and not isinstance(addon_profiles, list):
            raise TypeError("Expected argument 'addon_profiles' to be a list")
        __self__.addon_profiles = addon_profiles
        """
        A `addon_profile` block as documented below.
        """
        if agent_pool_profiles and not isinstance(agent_pool_profiles, list):
            raise TypeError("Expected argument 'agent_pool_profiles' to be a list")
        __self__.agent_pool_profiles = agent_pool_profiles
        """
        An `agent_pool_profile` block as documented below.
        """
        if dns_prefix and not isinstance(dns_prefix, str):
            raise TypeError("Expected argument 'dns_prefix' to be a str")
        __self__.dns_prefix = dns_prefix
        """
        The DNS Prefix of the managed Kubernetes cluster.
        """
        if fqdn and not isinstance(fqdn, str):
            raise TypeError("Expected argument 'fqdn' to be a str")
        __self__.fqdn = fqdn
        """
        The FQDN of the Azure Kubernetes Managed Cluster.
        """
        if kube_admin_configs and not isinstance(kube_admin_configs, list):
            raise TypeError("Expected argument 'kube_admin_configs' to be a list")
        __self__.kube_admin_configs = kube_admin_configs
        """
        A `kube_admin_config` block as defined below. This is only available when Role Based Access Control with Azure Active Directory is enabled.
        """
        if kube_admin_config_raw and not isinstance(kube_admin_config_raw, str):
            raise TypeError("Expected argument 'kube_admin_config_raw' to be a str")
        __self__.kube_admin_config_raw = kube_admin_config_raw
        """
        Raw Kubernetes config for the admin account to be used by [kubectl](https://kubernetes.io/docs/reference/kubectl/overview/) and other compatible tools. This is only available when Role Based Access Control with Azure Active Directory is enabled.
        """
        if kube_configs and not isinstance(kube_configs, list):
            raise TypeError("Expected argument 'kube_configs' to be a list")
        __self__.kube_configs = kube_configs
        """
        A `kube_config` block as defined below.
        """
        if kube_config_raw and not isinstance(kube_config_raw, str):
            raise TypeError("Expected argument 'kube_config_raw' to be a str")
        __self__.kube_config_raw = kube_config_raw
        """
        Base64 encoded Kubernetes configuration.
        """
        if kubernetes_version and not isinstance(kubernetes_version, str):
            raise TypeError("Expected argument 'kubernetes_version' to be a str")
        __self__.kubernetes_version = kubernetes_version
        """
        The version of Kubernetes used on the managed Kubernetes Cluster.
        """
        if linux_profiles and not isinstance(linux_profiles, list):
            raise TypeError("Expected argument 'linux_profiles' to be a list")
        __self__.linux_profiles = linux_profiles
        """
        A `linux_profile` block as documented below.
        """
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        __self__.location = location
        """
        The Azure Region in which the managed Kubernetes Cluster exists.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        """
        The name assigned to this pool of agents.
        """
        if network_profiles and not isinstance(network_profiles, list):
            raise TypeError("Expected argument 'network_profiles' to be a list")
        __self__.network_profiles = network_profiles
        """
        A `network_profile` block as documented below.
        """
        if node_resource_group and not isinstance(node_resource_group, str):
            raise TypeError("Expected argument 'node_resource_group' to be a str")
        __self__.node_resource_group = node_resource_group
        """
        Auto-generated Resource Group containing AKS Cluster resources.
        """
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        __self__.resource_group_name = resource_group_name
        if role_based_access_controls and not isinstance(role_based_access_controls, list):
            raise TypeError("Expected argument 'role_based_access_controls' to be a list")
        __self__.role_based_access_controls = role_based_access_controls
        """
        A `role_based_access_control` block as documented below.
        """
        if service_principals and not isinstance(service_principals, list):
            raise TypeError("Expected argument 'service_principals' to be a list")
        __self__.service_principals = service_principals
        """
        A `service_principal` block as documented below.
        """
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        __self__.tags = tags
        """
        A mapping of tags assigned to this resource.
        """
        if windows_profiles and not isinstance(windows_profiles, list):
            raise TypeError("Expected argument 'windows_profiles' to be a list")
        __self__.windows_profiles = windows_profiles
        """
        A `windows_profile` block as documented below.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetKubernetesClusterResult(GetKubernetesClusterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKubernetesClusterResult(
            addon_profiles=self.addon_profiles,
            agent_pool_profiles=self.agent_pool_profiles,
            dns_prefix=self.dns_prefix,
            fqdn=self.fqdn,
            kube_admin_configs=self.kube_admin_configs,
            kube_admin_config_raw=self.kube_admin_config_raw,
            kube_configs=self.kube_configs,
            kube_config_raw=self.kube_config_raw,
            kubernetes_version=self.kubernetes_version,
            linux_profiles=self.linux_profiles,
            location=self.location,
            name=self.name,
            network_profiles=self.network_profiles,
            node_resource_group=self.node_resource_group,
            resource_group_name=self.resource_group_name,
            role_based_access_controls=self.role_based_access_controls,
            service_principals=self.service_principals,
            tags=self.tags,
            windows_profiles=self.windows_profiles,
            id=self.id)

def get_kubernetes_cluster(name=None,resource_group_name=None,opts=None):
    """
    Use this data source to access information about an existing Managed Kubernetes Cluster (AKS).
    
    > **Note:** All arguments including the client secret will be stored in the raw state as plain-text.
    [Read more about sensitive data in state](https://www.terraform.io/docs/state/sensitive-data.html).
    
    :param str name: The name of the managed Kubernetes Cluster.
    :param str resource_group_name: The name of the Resource Group in which the managed Kubernetes Cluster exists.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/d/kubernetes_cluster.html.markdown.
    """
    __args__ = dict()

    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure:containerservice/getKubernetesCluster:getKubernetesCluster', __args__, opts=opts).value

    return AwaitableGetKubernetesClusterResult(
        addon_profiles=__ret__.get('addonProfiles'),
        agent_pool_profiles=__ret__.get('agentPoolProfiles'),
        dns_prefix=__ret__.get('dnsPrefix'),
        fqdn=__ret__.get('fqdn'),
        kube_admin_configs=__ret__.get('kubeAdminConfigs'),
        kube_admin_config_raw=__ret__.get('kubeAdminConfigRaw'),
        kube_configs=__ret__.get('kubeConfigs'),
        kube_config_raw=__ret__.get('kubeConfigRaw'),
        kubernetes_version=__ret__.get('kubernetesVersion'),
        linux_profiles=__ret__.get('linuxProfiles'),
        location=__ret__.get('location'),
        name=__ret__.get('name'),
        network_profiles=__ret__.get('networkProfiles'),
        node_resource_group=__ret__.get('nodeResourceGroup'),
        resource_group_name=__ret__.get('resourceGroupName'),
        role_based_access_controls=__ret__.get('roleBasedAccessControls'),
        service_principals=__ret__.get('servicePrincipals'),
        tags=__ret__.get('tags'),
        windows_profiles=__ret__.get('windowsProfiles'),
        id=__ret__.get('id'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Job(pulumi.CustomResource):
    action_storage_queue: pulumi.Output[dict]
    """
    A `action_storage_queue` block defining a storage queue job action as described below. Note this is identical to an `error_action_storage_queue` block.
    
      * `message` (`str`)
      * `sasToken` (`str`)
      * `storageAccountName` (`str`)
      * `storageQueueName` (`str`)
    """
    action_web: pulumi.Output[dict]
    """
    A `action_web` block defining the job action as described below. Note this is identical to an `error_action_web` block.
    
      * `authenticationActiveDirectory` (`dict`)
    
        * `audience` (`str`)
        * `client_id` (`str`)
        * `secret` (`str`)
        * `tenant_id` (`str`)
    
      * `authenticationBasic` (`dict`)
    
        * `password` (`str`)
        * `username` (`str`)
    
      * `authenticationCertificate` (`dict`)
    
        * `expiration` (`str`) - (Computed)  The certificate expiration date.
        * `password` (`str`)
        * `pfx` (`str`)
        * `subject_name` (`str`) - (Computed) The certificate's certificate subject name.
        * `thumbprint` (`str`) - (Computed) The certificate thumbprint.
    
      * `body` (`str`)
      * `headers` (`dict`)
      * `method` (`str`)
      * `url` (`str`)
    """
    error_action_storage_queue: pulumi.Output[dict]
    """
    A `error_action_storage_queue` block defining the a web action to take on an error as described below. Note this is identical to an `action_storage_queue` block.
    
      * `message` (`str`)
      * `sasToken` (`str`)
      * `storageAccountName` (`str`)
      * `storageQueueName` (`str`)
    """
    error_action_web: pulumi.Output[dict]
    """
    A `error_action_web` block defining the action to take on an error as described below. Note this is identical to an `action_web` block.
    
      * `authenticationActiveDirectory` (`dict`)
    
        * `audience` (`str`)
        * `client_id` (`str`)
        * `secret` (`str`)
        * `tenant_id` (`str`)
    
      * `authenticationBasic` (`dict`)
    
        * `password` (`str`)
        * `username` (`str`)
    
      * `authenticationCertificate` (`dict`)
    
        * `expiration` (`str`) - (Computed)  The certificate expiration date.
        * `password` (`str`)
        * `pfx` (`str`)
        * `subject_name` (`str`) - (Computed) The certificate's certificate subject name.
        * `thumbprint` (`str`) - (Computed) The certificate thumbprint.
    
      * `body` (`str`)
      * `headers` (`dict`)
      * `method` (`str`)
      * `url` (`str`)
    """
    job_collection_name: pulumi.Output[str]
    """
    Specifies the name of the Scheduler Job Collection in which the Job should exist. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    The name of the Scheduler Job. Changing this forces a new resource to be created.
    """
    recurrence: pulumi.Output[dict]
    """
    A `recurrence` block defining a job occurrence schedule.
    
      * `count` (`float`)
      * `end_time` (`str`)
      * `frequency` (`str`)
      * `hours` (`list`)
      * `interval` (`float`)
      * `minutes` (`list`)
      * `month_days` (`list`)
      * `monthly_occurrences` (`list`)
    
        * `day` (`str`)
        * `occurrence` (`float`)
    
      * `week_days` (`list`)
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group in which to create the Scheduler Job. Changing this forces a new resource to be created.
    """
    retry: pulumi.Output[dict]
    """
    A `retry` block defining how to retry as described below.
    
      * `count` (`float`)
      * `interval` (`str`)
    """
    start_time: pulumi.Output[str]
    """
    The time the first instance of the job is to start running at.
    """
    state: pulumi.Output[str]
    """
    The sets or gets the current state of the job. Can be set to either `Enabled` or `Completed`
    """
    def __init__(__self__, resource_name, opts=None, action_storage_queue=None, action_web=None, error_action_storage_queue=None, error_action_web=None, job_collection_name=None, name=None, recurrence=None, resource_group_name=None, retry=None, start_time=None, state=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a Scheduler Job.
        
        > **NOTE:** Support for Scheduler Job has been deprecated by Microsoft in favour of Logic Apps ([more information can be found at this link](https://docs.microsoft.com/en-us/azure/scheduler/migrate-from-scheduler-to-logic-apps)) - as such we plan to remove support for this resource as a part of version 2.0 of the AzureRM Provider.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] action_storage_queue: A `action_storage_queue` block defining a storage queue job action as described below. Note this is identical to an `error_action_storage_queue` block.
        :param pulumi.Input[dict] action_web: A `action_web` block defining the job action as described below. Note this is identical to an `error_action_web` block.
        :param pulumi.Input[dict] error_action_storage_queue: A `error_action_storage_queue` block defining the a web action to take on an error as described below. Note this is identical to an `action_storage_queue` block.
        :param pulumi.Input[dict] error_action_web: A `error_action_web` block defining the action to take on an error as described below. Note this is identical to an `action_web` block.
        :param pulumi.Input[str] job_collection_name: Specifies the name of the Scheduler Job Collection in which the Job should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the Scheduler Job. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] recurrence: A `recurrence` block defining a job occurrence schedule.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the Scheduler Job. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] retry: A `retry` block defining how to retry as described below.
        :param pulumi.Input[str] start_time: The time the first instance of the job is to start running at.
        :param pulumi.Input[str] state: The sets or gets the current state of the job. Can be set to either `Enabled` or `Completed`
        
        The **action_storage_queue** object supports the following:
        
          * `message` (`pulumi.Input[str]`)
          * `sasToken` (`pulumi.Input[str]`)
          * `storageAccountName` (`pulumi.Input[str]`)
          * `storageQueueName` (`pulumi.Input[str]`)
        
        The **action_web** object supports the following:
        
          * `authenticationActiveDirectory` (`pulumi.Input[dict]`)
        
            * `audience` (`pulumi.Input[str]`)
            * `client_id` (`pulumi.Input[str]`)
            * `secret` (`pulumi.Input[str]`)
            * `tenant_id` (`pulumi.Input[str]`)
        
          * `authenticationBasic` (`pulumi.Input[dict]`)
        
            * `password` (`pulumi.Input[str]`)
            * `username` (`pulumi.Input[str]`)
        
          * `authenticationCertificate` (`pulumi.Input[dict]`)
        
            * `expiration` (`pulumi.Input[str]`) - (Computed)  The certificate expiration date.
            * `password` (`pulumi.Input[str]`)
            * `pfx` (`pulumi.Input[str]`)
            * `subject_name` (`pulumi.Input[str]`) - (Computed) The certificate's certificate subject name.
            * `thumbprint` (`pulumi.Input[str]`) - (Computed) The certificate thumbprint.
        
          * `body` (`pulumi.Input[str]`)
          * `headers` (`pulumi.Input[dict]`)
          * `method` (`pulumi.Input[str]`)
          * `url` (`pulumi.Input[str]`)
        
        The **error_action_storage_queue** object supports the following:
        
          * `message` (`pulumi.Input[str]`)
          * `sasToken` (`pulumi.Input[str]`)
          * `storageAccountName` (`pulumi.Input[str]`)
          * `storageQueueName` (`pulumi.Input[str]`)
        
        The **error_action_web** object supports the following:
        
          * `authenticationActiveDirectory` (`pulumi.Input[dict]`)
        
            * `audience` (`pulumi.Input[str]`)
            * `client_id` (`pulumi.Input[str]`)
            * `secret` (`pulumi.Input[str]`)
            * `tenant_id` (`pulumi.Input[str]`)
        
          * `authenticationBasic` (`pulumi.Input[dict]`)
        
            * `password` (`pulumi.Input[str]`)
            * `username` (`pulumi.Input[str]`)
        
          * `authenticationCertificate` (`pulumi.Input[dict]`)
        
            * `expiration` (`pulumi.Input[str]`) - (Computed)  The certificate expiration date.
            * `password` (`pulumi.Input[str]`)
            * `pfx` (`pulumi.Input[str]`)
            * `subject_name` (`pulumi.Input[str]`) - (Computed) The certificate's certificate subject name.
            * `thumbprint` (`pulumi.Input[str]`) - (Computed) The certificate thumbprint.
        
          * `body` (`pulumi.Input[str]`)
          * `headers` (`pulumi.Input[dict]`)
          * `method` (`pulumi.Input[str]`)
          * `url` (`pulumi.Input[str]`)
        
        The **recurrence** object supports the following:
        
          * `count` (`pulumi.Input[float]`)
          * `end_time` (`pulumi.Input[str]`)
          * `frequency` (`pulumi.Input[str]`)
          * `hours` (`pulumi.Input[list]`)
          * `interval` (`pulumi.Input[float]`)
          * `minutes` (`pulumi.Input[list]`)
          * `month_days` (`pulumi.Input[list]`)
          * `monthly_occurrences` (`pulumi.Input[list]`)
        
            * `day` (`pulumi.Input[str]`)
            * `occurrence` (`pulumi.Input[float]`)
        
          * `week_days` (`pulumi.Input[list]`)
        
        The **retry** object supports the following:
        
          * `count` (`pulumi.Input[float]`)
          * `interval` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/scheduler_job.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['action_storage_queue'] = action_storage_queue
            __props__['action_web'] = action_web
            __props__['error_action_storage_queue'] = error_action_storage_queue
            __props__['error_action_web'] = error_action_web
            if job_collection_name is None:
                raise TypeError("Missing required property 'job_collection_name'")
            __props__['job_collection_name'] = job_collection_name
            __props__['name'] = name
            __props__['recurrence'] = recurrence
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['retry'] = retry
            __props__['start_time'] = start_time
            __props__['state'] = state
        super(Job, __self__).__init__(
            'azure:scheduler/job:Job',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, action_storage_queue=None, action_web=None, error_action_storage_queue=None, error_action_web=None, job_collection_name=None, name=None, recurrence=None, resource_group_name=None, retry=None, start_time=None, state=None):
        """
        Get an existing Job resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] action_storage_queue: A `action_storage_queue` block defining a storage queue job action as described below. Note this is identical to an `error_action_storage_queue` block.
        :param pulumi.Input[dict] action_web: A `action_web` block defining the job action as described below. Note this is identical to an `error_action_web` block.
        :param pulumi.Input[dict] error_action_storage_queue: A `error_action_storage_queue` block defining the a web action to take on an error as described below. Note this is identical to an `action_storage_queue` block.
        :param pulumi.Input[dict] error_action_web: A `error_action_web` block defining the action to take on an error as described below. Note this is identical to an `action_web` block.
        :param pulumi.Input[str] job_collection_name: Specifies the name of the Scheduler Job Collection in which the Job should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the Scheduler Job. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] recurrence: A `recurrence` block defining a job occurrence schedule.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the Scheduler Job. Changing this forces a new resource to be created.
        :param pulumi.Input[dict] retry: A `retry` block defining how to retry as described below.
        :param pulumi.Input[str] start_time: The time the first instance of the job is to start running at.
        :param pulumi.Input[str] state: The sets or gets the current state of the job. Can be set to either `Enabled` or `Completed`
        
        The **action_storage_queue** object supports the following:
        
          * `message` (`pulumi.Input[str]`)
          * `sasToken` (`pulumi.Input[str]`)
          * `storageAccountName` (`pulumi.Input[str]`)
          * `storageQueueName` (`pulumi.Input[str]`)
        
        The **action_web** object supports the following:
        
          * `authenticationActiveDirectory` (`pulumi.Input[dict]`)
        
            * `audience` (`pulumi.Input[str]`)
            * `client_id` (`pulumi.Input[str]`)
            * `secret` (`pulumi.Input[str]`)
            * `tenant_id` (`pulumi.Input[str]`)
        
          * `authenticationBasic` (`pulumi.Input[dict]`)
        
            * `password` (`pulumi.Input[str]`)
            * `username` (`pulumi.Input[str]`)
        
          * `authenticationCertificate` (`pulumi.Input[dict]`)
        
            * `expiration` (`pulumi.Input[str]`) - (Computed)  The certificate expiration date.
            * `password` (`pulumi.Input[str]`)
            * `pfx` (`pulumi.Input[str]`)
            * `subject_name` (`pulumi.Input[str]`) - (Computed) The certificate's certificate subject name.
            * `thumbprint` (`pulumi.Input[str]`) - (Computed) The certificate thumbprint.
        
          * `body` (`pulumi.Input[str]`)
          * `headers` (`pulumi.Input[dict]`)
          * `method` (`pulumi.Input[str]`)
          * `url` (`pulumi.Input[str]`)
        
        The **error_action_storage_queue** object supports the following:
        
          * `message` (`pulumi.Input[str]`)
          * `sasToken` (`pulumi.Input[str]`)
          * `storageAccountName` (`pulumi.Input[str]`)
          * `storageQueueName` (`pulumi.Input[str]`)
        
        The **error_action_web** object supports the following:
        
          * `authenticationActiveDirectory` (`pulumi.Input[dict]`)
        
            * `audience` (`pulumi.Input[str]`)
            * `client_id` (`pulumi.Input[str]`)
            * `secret` (`pulumi.Input[str]`)
            * `tenant_id` (`pulumi.Input[str]`)
        
          * `authenticationBasic` (`pulumi.Input[dict]`)
        
            * `password` (`pulumi.Input[str]`)
            * `username` (`pulumi.Input[str]`)
        
          * `authenticationCertificate` (`pulumi.Input[dict]`)
        
            * `expiration` (`pulumi.Input[str]`) - (Computed)  The certificate expiration date.
            * `password` (`pulumi.Input[str]`)
            * `pfx` (`pulumi.Input[str]`)
            * `subject_name` (`pulumi.Input[str]`) - (Computed) The certificate's certificate subject name.
            * `thumbprint` (`pulumi.Input[str]`) - (Computed) The certificate thumbprint.
        
          * `body` (`pulumi.Input[str]`)
          * `headers` (`pulumi.Input[dict]`)
          * `method` (`pulumi.Input[str]`)
          * `url` (`pulumi.Input[str]`)
        
        The **recurrence** object supports the following:
        
          * `count` (`pulumi.Input[float]`)
          * `end_time` (`pulumi.Input[str]`)
          * `frequency` (`pulumi.Input[str]`)
          * `hours` (`pulumi.Input[list]`)
          * `interval` (`pulumi.Input[float]`)
          * `minutes` (`pulumi.Input[list]`)
          * `month_days` (`pulumi.Input[list]`)
          * `monthly_occurrences` (`pulumi.Input[list]`)
        
            * `day` (`pulumi.Input[str]`)
            * `occurrence` (`pulumi.Input[float]`)
        
          * `week_days` (`pulumi.Input[list]`)
        
        The **retry** object supports the following:
        
          * `count` (`pulumi.Input[float]`)
          * `interval` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/scheduler_job.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["action_storage_queue"] = action_storage_queue
        __props__["action_web"] = action_web
        __props__["error_action_storage_queue"] = error_action_storage_queue
        __props__["error_action_web"] = error_action_web
        __props__["job_collection_name"] = job_collection_name
        __props__["name"] = name
        __props__["recurrence"] = recurrence
        __props__["resource_group_name"] = resource_group_name
        __props__["retry"] = retry
        __props__["start_time"] = start_time
        __props__["state"] = state
        return Job(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class SqlServer(pulumi.CustomResource):
    administrator_login: pulumi.Output[str]
    """
    The administrator login name for the new server. Changing this forces a new resource to be created.
    """
    administrator_login_password: pulumi.Output[str]
    """
    The password associated with the `administrator_login` user. Needs to comply with Azure's [Password Policy](https://msdn.microsoft.com/library/ms161959.aspx)
    """
    fully_qualified_domain_name: pulumi.Output[str]
    """
    The fully qualified domain name of the Azure SQL Server (e.g. myServerName.database.windows.net)
    """
    identity: pulumi.Output[dict]
    """
    An `identity` block as defined below.
    
      * `principal_id` (`str`) - The Principal ID for the Service Principal associated with the Identity of this SQL Server.
      * `tenant_id` (`str`) - The Tenant ID for the Service Principal associated with the Identity of this SQL Server.
      * `type` (`str`)
    """
    location: pulumi.Output[str]
    """
    Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    The name of the SQL Server. This needs to be globally unique within Azure.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group in which to create the SQL Server.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    version: pulumi.Output[str]
    """
    The version for the new server. Valid values are: 2.0 (for v11 server) and 12.0 (for v12 server).
    """
    def __init__(__self__, resource_name, opts=None, administrator_login=None, administrator_login_password=None, identity=None, location=None, name=None, resource_group_name=None, tags=None, version=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a SQL Azure Database Server.
        
        > **Note:** All arguments including the administrator login and password will be stored in the raw state as plain-text.
        [Read more about sensitive data in state](https://www.terraform.io/docs/state/sensitive-data.html).
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] administrator_login: The administrator login name for the new server. Changing this forces a new resource to be created.
        :param pulumi.Input[str] administrator_login_password: The password associated with the `administrator_login` user. Needs to comply with Azure's [Password Policy](https://msdn.microsoft.com/library/ms161959.aspx)
        :param pulumi.Input[dict] identity: An `identity` block as defined below.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the SQL Server. This needs to be globally unique within Azure.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the SQL Server.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] version: The version for the new server. Valid values are: 2.0 (for v11 server) and 12.0 (for v12 server).
        
        The **identity** object supports the following:
        
          * `principal_id` (`pulumi.Input[str]`) - The Principal ID for the Service Principal associated with the Identity of this SQL Server.
          * `tenant_id` (`pulumi.Input[str]`) - The Tenant ID for the Service Principal associated with the Identity of this SQL Server.
          * `type` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/sql_server.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if administrator_login is None:
                raise TypeError("Missing required property 'administrator_login'")
            __props__['administrator_login'] = administrator_login
            if administrator_login_password is None:
                raise TypeError("Missing required property 'administrator_login_password'")
            __props__['administrator_login_password'] = administrator_login_password
            __props__['identity'] = identity
            __props__['location'] = location
            __props__['name'] = name
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['tags'] = tags
            if version is None:
                raise TypeError("Missing required property 'version'")
            __props__['version'] = version
            __props__['fully_qualified_domain_name'] = None
        super(SqlServer, __self__).__init__(
            'azure:sql/sqlServer:SqlServer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, administrator_login=None, administrator_login_password=None, fully_qualified_domain_name=None, identity=None, location=None, name=None, resource_group_name=None, tags=None, version=None):
        """
        Get an existing SqlServer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] administrator_login: The administrator login name for the new server. Changing this forces a new resource to be created.
        :param pulumi.Input[str] administrator_login_password: The password associated with the `administrator_login` user. Needs to comply with Azure's [Password Policy](https://msdn.microsoft.com/library/ms161959.aspx)
        :param pulumi.Input[str] fully_qualified_domain_name: The fully qualified domain name of the Azure SQL Server (e.g. myServerName.database.windows.net)
        :param pulumi.Input[dict] identity: An `identity` block as defined below.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the SQL Server. This needs to be globally unique within Azure.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the SQL Server.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] version: The version for the new server. Valid values are: 2.0 (for v11 server) and 12.0 (for v12 server).
        
        The **identity** object supports the following:
        
          * `principal_id` (`pulumi.Input[str]`) - The Principal ID for the Service Principal associated with the Identity of this SQL Server.
          * `tenant_id` (`pulumi.Input[str]`) - The Tenant ID for the Service Principal associated with the Identity of this SQL Server.
          * `type` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/sql_server.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["administrator_login"] = administrator_login
        __props__["administrator_login_password"] = administrator_login_password
        __props__["fully_qualified_domain_name"] = fully_qualified_domain_name
        __props__["identity"] = identity
        __props__["location"] = location
        __props__["name"] = name
        __props__["resource_group_name"] = resource_group_name
        __props__["tags"] = tags
        __props__["version"] = version
        return SqlServer(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class RouteTable(pulumi.CustomResource):
    disable_bgp_route_propagation: pulumi.Output[bool]
    """
    Boolean flag which controls propagation of routes learned by BGP on that route table. True means disable.
    """
    location: pulumi.Output[str]
    """
    Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
    """
    name: pulumi.Output[str]
    """
    The name of the route.
    """
    resource_group_name: pulumi.Output[str]
    """
    The name of the resource group in which to create the route table. Changing this forces a new resource to be created.
    """
    routes: pulumi.Output[list]
    """
    [List of objects](https://www.terraform.io/docs/configuration/attr-as-blocks.html) representing routes. Each object accepts the arguments documented below.
    
      * `address_prefix` (`str`) - The destination CIDR to which the route applies, such as 10.1.0.0/16
      * `name` (`str`) - The name of the route.
      * `next_hop_in_ip_address` (`str`) - Contains the IP address packets should be forwarded to. Next hop values are only allowed in routes where the next hop type is `VirtualAppliance`.
      * `next_hop_type` (`str`) - The type of Azure hop the packet should be sent to. Possible values are `VirtualNetworkGateway`, `VnetLocal`, `Internet`, `VirtualAppliance` and `None`.
    """
    subnets: pulumi.Output[list]
    """
    The collection of Subnets associated with this route table.
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the resource.
    """
    def __init__(__self__, resource_name, opts=None, disable_bgp_route_propagation=None, location=None, name=None, resource_group_name=None, routes=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a Route Table
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] disable_bgp_route_propagation: Boolean flag which controls propagation of routes learned by BGP on that route table. True means disable.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the route.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the route table. Changing this forces a new resource to be created.
        :param pulumi.Input[list] routes: [List of objects](https://www.terraform.io/docs/configuration/attr-as-blocks.html) representing routes. Each object accepts the arguments documented below.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        
        The **routes** object supports the following:
        
          * `address_prefix` (`pulumi.Input[str]`) - The destination CIDR to which the route applies, such as 10.1.0.0/16
          * `name` (`pulumi.Input[str]`) - The name of the route.
          * `next_hop_in_ip_address` (`pulumi.Input[str]`) - Contains the IP address packets should be forwarded to. Next hop values are only allowed in routes where the next hop type is `VirtualAppliance`.
          * `next_hop_type` (`pulumi.Input[str]`) - The type of Azure hop the packet should be sent to. Possible values are `VirtualNetworkGateway`, `VnetLocal`, `Internet`, `VirtualAppliance` and `None`.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/route_table.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['disable_bgp_route_propagation'] = disable_bgp_route_propagation
            __props__['location'] = location
            __props__['name'] = name
            if resource_group_name is None:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__['resource_group_name'] = resource_group_name
            __props__['routes'] = routes
            __props__['tags'] = tags
            __props__['subnets'] = None
        super(RouteTable, __self__).__init__(
            'azure:network/routeTable:RouteTable',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, disable_bgp_route_propagation=None, location=None, name=None, resource_group_name=None, routes=None, subnets=None, tags=None):
        """
        Get an existing RouteTable resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] disable_bgp_route_propagation: Boolean flag which controls propagation of routes learned by BGP on that route table. True means disable.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the route.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the route table. Changing this forces a new resource to be created.
        :param pulumi.Input[list] routes: [List of objects](https://www.terraform.io/docs/configuration/attr-as-blocks.html) representing routes. Each object accepts the arguments documented below.
        :param pulumi.Input[list] subnets: The collection of Subnets associated with this route table.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the resource.
        
        The **routes** object supports the following:
        
          * `address_prefix` (`pulumi.Input[str]`) - The destination CIDR to which the route applies, such as 10.1.0.0/16
          * `name` (`pulumi.Input[str]`) - The name of the route.
          * `next_hop_in_ip_address` (`pulumi.Input[str]`) - Contains the IP address packets should be forwarded to. Next hop values are only allowed in routes where the next hop type is `VirtualAppliance`.
          * `next_hop_type` (`pulumi.Input[str]`) - The type of Azure hop the packet should be sent to. Possible values are `VirtualNetworkGateway`, `VnetLocal`, `Internet`, `VirtualAppliance` and `None`.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-azurerm/blob/master/website/docs/r/route_table.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["disable_bgp_route_propagation"] = disable_bgp_route_propagation
        __props__["location"] = location
        __props__["name"] = name
        __props__["resource_group_name"] = resource_group_name
        __props__["routes"] = routes
        __props__["subnets"] = subnets
        __props__["tags"] = tags
        return RouteTable(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .service import *
from .api import *
from .api_operation import *
from .api_operation_policy import *
from .api_policy import *
from .api_schema import *
from .api_version_set import *
from .authorization_server import *
from .backend import *
from .certificate import *
from .group import *
from .group_user import *
from .logger import *
from .open_id_connect_provider import *
from .product import *
from .product_api import *
from .product_group import *
from .product_policy import *
from .property import *
from .subscription import *
from .user import *
from .get_service import *
from .get_api import *
from .get_group import *
from .get_product import *
from .get_user import *
